Tutorials
=========

There is a small number of tutorials that will be extended if I find
support. Those are Jupyter notebooks on the branch "scripts" with
names starting with "tutorial". The notebooks will be available locally
in a directory named "scripts" after installing cryoswath and running
cryoswath-init. Otherwise, you can view them online by selecting the
"scripts" branch on GitHub's project main page.

`tutorial__general_step-by-step.ipynb
<https://github.com/j-haacker/cryoswath/blob/scripts/tutorial__general_step-by-step.ipynb>`_
contains a step-by-step guide to retrieve gridded glacier surface
elevation trends from raw (L1b) data.

`tutorial__process_first_waveform.ipynb
<https://github.com/j-haacker/cryoswath/blob/scripts/tutorial__process_first_waveform.ipynb>`_
explains how to visualize single waveforms.

`tutorial__process_first_swath.ipynb
<https://github.com/j-haacker/cryoswath/blob/scripts/tutorial__process_first_swath.ipynb>`_
teaches the retrieval of elevation estimates for a ceratin satellite track.

`tutorial__poca.ipynb
<https://github.com/j-haacker/cryoswath/blob/scripts/tutorial__poca.ipynb>`_
shows how the points of closest approach (POCA), that have a special
meaning, can be retrieved.
